/****************************************************************************
** $Id: qt/examples/mdi/application.cpp   2.2.0-beta2   edited 2000-08-05 $
**
** Copyright (C) 1992-2000 Troll Tech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/

#include "application.h"
#include <qworkspace.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qfile.h>
#include <qfiledialog.h>
#include <qlabel.h>
#include <qstatusbar.h>
#include <qmessagebox.h>
#include <qprinter.h>
#include <qapplication.h>
#include <qpushbutton.h>
#include <qaccel.h>
#include <qtextstream.h>
#include <qwhatsthis.h>
#include <qobjectlist.h>
#include <qvbox.h>
#include <qbuttongroup.h>
#include <qwidget.h>
#include <qcursor.h>


#include "filesave.xpm"
#include "fileopen.xpm"

// Chemistry Tools XPM

#include "arrow.xpm"
#include "cpentane.xpm"
#include "chemline.xpm"
#include "chemtext.xpm"
#include "chemhexane.xpm"
#include "aromatic.xpm"
#include "sbunder.xpm"
#include "sbhigh.xpm"
#include "rotate.xpm"
#include "cpentadiene.xpm"

ApplicationWindow::ApplicationWindow()
    : QMainWindow( 0, "chem2D", WDestructiveClose )
{
    int id;

    QPixmap openIcon, saveIcon;

    fileTools = new QToolBar( this, tr("file operations") );
    addToolBar( fileTools, tr( "File Operations" ), Top, TRUE );

    openIcon = QPixmap( fileopen );
    QToolButton * fileOpen
	= new QToolButton( openIcon, tr("Open File"), QString::null,
			   this, SLOT(load()), fileTools, tr("open file") );

    saveIcon = QPixmap( filesave );
    QToolButton * fileSave
	= new QToolButton( saveIcon, tr("Save File"), QString::null,
			   this, SLOT(save()), fileTools, tr("save file") );

#ifndef QT_NO_PRINTER
    printer = new QPrinter;
    QPixmap printIcon;

    printIcon = QPixmap( filesave );
    QToolButton* filePrint = new QToolButton(printIcon, tr("Print File"), QString::null,
			   this, SLOT(print()), fileTools, tr("print file") );
#endif


    QPopupMenu * file = new QPopupMenu( this );
    menuBar()->insertItem( tr("&File"), file );

    file->insertItem( tr("&New"), this, SLOT(newDoc()), CTRL+Key_N );

    id = file->insertItem( openIcon, tr("&Open"),
			   this, SLOT(load()), CTRL+Key_O );

    id = file->insertItem( saveIcon, tr("&Save"),
			   this, SLOT(save()), CTRL+Key_S );
    id = file->insertItem( tr("Save &as..."), this, SLOT(saveAs()) );
#ifndef QT_NO_PRINTER
    file->insertSeparator();
    id = file->insertItem( printIcon, tr("&Print"),
			   this, SLOT(print()), CTRL+Key_P );
#endif
    file->insertSeparator();
    file->insertItem( tr("&Close"), this, SLOT(closeWindow()), CTRL+Key_W );
    file->insertItem( tr("&Quit"), qApp, SLOT( closeAllWindows() ), CTRL+Key_Q );

    windowsMenu = new QPopupMenu( this );
    windowsMenu->setCheckable( TRUE );
    connect(windowsMenu, SIGNAL(aboutToShow()),
                        SLOT(windowsMenuAboutToShow()));
    menuBar()->insertItem( tr("&Windows"), windowsMenu );

    menuBar()->insertSeparator();
    QPopupMenu * help = new QPopupMenu( this );
    menuBar()->insertItem( tr("&Help"), help );

    help->insertItem( tr("&About"), this, SLOT(about()), Key_F1);
    help->insertItem( tr("About&Qt"), this, SLOT(aboutQt()));
    help->insertSeparator();

    QVBox* vb = new QVBox( this );
    vb->setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
    ws = new QWorkspace( vb );
    setCentralWidget( vb );
    chemistryTools = 0;

    statusBar()->message( tr("Ready"), 2000 );

}


ApplicationWindow::~ApplicationWindow()
{
#ifndef QT_NO_PRINTER
    delete printer;
#endif
}

// Create the toolbar for chemistry

void ApplicationWindow::CreateChemistryTools()
{
  QPixmap chemArrow, chemBond, chemSbunder, chemSbhigh, chemText, chemPentane,
          chemHexane, chemAromatic, chemRotate,  chemCPentadiene;
  
  if(chemistryTools)
    return;
  else
  {
   chemistryTools = new QToolBar( this, tr("Chemistry Palette"));
   addToolBar(chemistryTools, tr("Chemistry Operations"), Right, TRUE);
   chemistryTools->show();
   // Add Group
   QButtonGroup *chemistryGroup = new QButtonGroup(2, QGroupBox::Horizontal,
                                                   "", chemistryTools);
   chemistryGroup->setExclusive(TRUE);

   // Add buttons
   chemArrow = QPixmap( arrow_xpm );
   QPushButton* btArrow = new QPushButton(chemistryGroup);
   btArrow->setToggleButton(TRUE);
   btArrow->setPixmap(chemArrow);
   btArrow->setFlat(TRUE);
   btArrow->resize(16, 16);


   chemBond = QPixmap( chemline_xpm );
   QPushButton* btBond = new QPushButton(chemistryGroup);
   btBond->setToggleButton(TRUE);
   btBond->setPixmap(chemBond);
   btBond->setFlat(TRUE);
   btBond->resize(16, 16);

   chemSbunder = QPixmap( sbunder_xpm );
   QPushButton* btSbunder = new QPushButton(chemistryGroup);
   btSbunder->setToggleButton(TRUE);
   btSbunder->setPixmap(chemSbunder);
   btSbunder->setFlat(TRUE);
   btSbunder->resize(16, 16); 

   chemSbhigh = QPixmap( sbhigh_xpm );
   QPushButton* btSbhigh = new QPushButton(chemistryGroup);
   btSbhigh->setToggleButton(TRUE);
   btSbhigh->setPixmap(chemSbhigh);
   btSbhigh->setFlat(TRUE);
   btSbhigh->resize(16, 16);

   chemText = QPixmap( chemtext_xpm );
   QPushButton* btText = new QPushButton(chemistryGroup);
   btText->setPixmap( chemText );
   btText->setToggleButton(TRUE);
   btText->setFlat(TRUE);
   btText->resize(16, 16);

   chemPentane = QPixmap( cpentane_xpm );
   QPushButton* btPentane = new QPushButton(chemistryGroup);
   btPentane->setPixmap( chemPentane );
   btPentane->setToggleButton(TRUE);
   btPentane->setFlat(TRUE);
   btPentane->resize(16, 16);

   chemHexane = QPixmap( chemhexane_xpm );
   QPushButton* btHexane = new QPushButton(chemistryGroup);
   btHexane->setPixmap( chemHexane );
   btHexane->setToggleButton(TRUE);
   btHexane->setFlat(TRUE);
   btHexane->resize(16, 16);


   chemAromatic = QPixmap( aromatic_xpm );
   QPushButton* btAromatic = new QPushButton(chemistryGroup);
   btAromatic->setPixmap( chemAromatic );
   btAromatic->setToggleButton(TRUE);
   btAromatic->setFlat(TRUE);
   btAromatic->resize(16, 16);

  chemRotate = QPixmap( rotate_xpm );
   QPushButton* btRotate = new QPushButton(chemistryGroup);
   btRotate->setPixmap( chemRotate );
   btRotate->setToggleButton(TRUE);
   btRotate->setFlat(TRUE);
   btRotate->resize(16, 16);

   chemCPentadiene = QPixmap( cpentadiene );
   QPushButton* btCPentadiene = new QPushButton(chemistryGroup);
   btCPentadiene->setPixmap( chemCPentadiene );
   btCPentadiene->setToggleButton(TRUE);
   btCPentadiene->setFlat(TRUE);
   btCPentadiene->resize(16, 16);



   chemistryGroup->setButton(0);
   
   connect( chemistryGroup, SIGNAL( clicked(int) ), this, SLOT(ToolToggled(int)) );
  }
}


chem2DEditor* ApplicationWindow::newDoc()
{



    CreateChemistryTools();

    chem2DEditor* w = new chem2DEditor(0, ws, 0, WDestructiveClose );
    w->setCaption(tr("Untitled Chemical"));
    w->setIcon( QPixmap("document.xpm") );
    w->show();
    return w;
}

void ApplicationWindow::load()
{
    QString fn = QFileDialog::getOpenFileName( QString::null, QString::null, this );
    if ( !fn.isEmpty() ) {
	chem2DEditor *w  = newDoc();
//	w->load( fn );
    }  else {
	statusBar()->message( tr("Loading aborted"), 2000 );
    }
}

void ApplicationWindow::save()
{
  /*  chem2DEditor* m = (chem2DEditor*)ws->activeWindow();
    if ( m )
	m->save();*/
}


void ApplicationWindow::saveAs()
{
  /*  chem2DEditor* m = (chem2DEditoe*)ws->activeWindow();
    if ( m )
	m->saveAs();*/
}


void ApplicationWindow::print()
{
}


void ApplicationWindow::closeWindow()
{
    chem2DEditor* m = (chem2DEditor*)ws->activeWindow();
    if ( m )
	m->close();
}

void ApplicationWindow::about()
{
    QMessageBox::about( this, tr("Chem2D - Chemsuite"),
			tr("Chem2D - Chemsuite Development\n "
			"This program is part of Chemsuite."));
}


void ApplicationWindow::aboutQt()
{
    QMessageBox::aboutQt( this, "Chemsuite chem2D" );
}


void ApplicationWindow::windowsMenuAboutToShow()
{
    windowsMenu->clear();
    int cascadeId = windowsMenu->insertItem(tr("&Cascade"), ws, SLOT(cascade() ) );
    int tileId = windowsMenu->insertItem(tr("&Tile"), ws, SLOT(tile() ) );
    if ( ws->windowList().isEmpty() ) {
	windowsMenu->setItemEnabled( cascadeId, FALSE );
	windowsMenu->setItemEnabled( tileId, FALSE );
    }
    windowsMenu->insertSeparator();
    QWidgetList windows = ws->windowList();
    for ( int i = 0; i < int(windows.count()); ++i ) {
	int id = windowsMenu->insertItem(windows.at(i)->caption(),
					 this, SLOT( windowsMenuActivated( int ) ) );
	windowsMenu->setItemParameter( id, i );
	windowsMenu->setItemChecked( id, ws->activeWindow() == windows.at(i) );
    }
}

void ApplicationWindow::windowsMenuActivated( int id )
{
    QWidget* w = ws->windowList().at( id );
    if ( w )
	w->setFocus();
}

// Tool Selected

void ApplicationWindow::ToolToggled(int id)
{
        chem2DEditor *m;
        SelectedTool = (TOOL) id;
        for(unsigned int i=0;i < ws->windowList().count();i++)
           {
            m = dynamic_cast<chem2DEditor*> (ws->windowList().at(i));
            if(m)
             {
              m->Selected = SelectedTool;
              if(SelectedTool==SELECT_TOOL)
                m->setCursor( QCursor( arrowCursor ) ); else
                m->setCursor( QCursor( crossCursor ) );
             }
            qDebug("Item %d Tool %d", i, id);
           }
        
}


